Zap Imoveis
============

ZAP Imóveis crawler and scraper using beautifulsoup4.

Usage example
-------------
    Para utilizar em sua aplicação basta instanciar
    passando os parâmetros da pesquisa.
    # Exemplo: zapimoveis_scraper.search(localization="go+goiania++setor-oeste", num_pages=5)

Installing
----------
    pip install zapimoveis_scraper
